# pdf-renamer

pdf-renamer is a Python library to automatically rename the pdf files of a scientific paper, or in general any publication which can be associated to a [DOI](http://dx.doi.org) or
other identifiers (e.g. [arXiv](https://arxiv.org)). It can be used to address single files or to scan entire folders and sub-folders.
The format of the filename can be specified by the user by choosing among several tags. 


## Description
To DO.

## To Do
-check if file with the same filename already exists in folder


## Installation

Use the package manager pip to install pdf_renamer.

```bash
pip install pdf-renamer
```

## Usage

pdf_renamer can be used either as a stand-alone application invoked from the command line, or by importing it in your python project.

### Usage inside a python script:
TO DO

### Command line usage:
TO DO
## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.


## License
[MIT](https://choosealicense.com/licenses/mit/)